<h1 align="center"><img src="https://github.com/CoffeeStraw/PyonFX/blob/master/docs/source/_static/PyonFX%20Logo.png?raw=true" alt="PyonFX Logo" width="600"></h1>

<h4 align="center">An easy way to create KFX (Karaoke Effects) and complex typesetting using the ASS format (Advanced Substation Alpha).</h4>
<p align="center">Powered by <b>Python3</b>, PyonFX aims to offer <b>stability</b>, <b>efficiency</b>, and <b>ease of use</b> to anyone who wants to create something more visually complex within ASS.</p>

<p align="center"><a href="https://discord.gg/Xxy3YAv"><img src="https://img.shields.io/discord/562766544061595650.svg?label=Discord%20Server&logo=discord&style=for-the-badge" alt="Discord Official Server"></a> <br> <a href="https://www.python.org/"><img src="https://img.shields.io/pypi/pyversions/pyonfx?style=for-the-badge" alt="PyPI - Python Version"></a> <img src="https://img.shields.io/pypi/v/pyonfx?style=for-the-badge" alt="PyPI - Version"></p>

<p align="center"><img src="https://github.com/CoffeeStraw/PyonFX/blob/master/docs/source/_static/PyonFX_Showcase.jpg?raw=true" alt="Showcase of Effects doable with PyonFX"></p>

# Documentation

You can find the full documentation of PyonFX, as well as a quick-start guide and examples, on [Read The Docs](http://pyonfx.rtfd.io/).

## Contributing

If you want to contribute to PyonFX, please make sure to review the [contribution
guidelines](https://github.com/CoffeeStraw/PyonFX/blob/master/CONTRIBUTING.md).

This project makes use of [GitHub issues](https://github.com/CoffeeStraw/PyonFX/issues) for
tracking **requests and bugs only**, so please *don't* use issues for general questions and discussion.

## License

This project is licensed under the LGPL v3.0 License — see the [LICENSE](https://github.com/CoffeeStraw/PyonFX/blob/master/LICENSE) file for further details.

## Acknowledgments

* **[Youka](https://github.com/Youka)** for the original main functions ideas for **[NyuFX](https://github.com/Youka/NyuFX)**;
* **[McWhite](https://github.com/BastianGanze)** for the original functions ideas of his library for **[NyuFX](https://github.com/Youka/NyuFX)**;
* **[moi15moi](https://github.com/moi15moi)** for creating **[VideoTimestamps](https://github.com/moi15moi/VideoTimestamps)** and contributing significant improvements to the frame processing utilities;
* **Siplas** for helping me out in the realization of the current logo for **PyonFX**;
* **Preacer** for the name suggestion.
